.\" Copyright 2009 The Archiveopteryx Developers <info@aox.org>
.TH aox 8 2013-12-02 aox.org "Archiveopteryx Documentation"
.SH NAME
aox - management tool for Archiveopteryx.
.SH SYNOPSIS
.B $BINDIR/aox
.I verb
.I noun
[
.I options
] [
.I arguments
]
.PP
.B aox help commands
.PP
.B aox help
.I command
.SH DESCRIPTION
.nh
.PP
.B aox
is a command-line program to perform various system administration
tasks for Archiveopteryx.
.PP
Examples of such tasks are adding users, changing the access control
for mailboxes, etc. In principle, everything one would want to do
using a shell script should be doable using
.BR aox .
.SH COMMANDS
.IP "aox start [-v]"
Starts the Archiveopteryx servers in the correct order.
.IP "aox stop [-v]"
Stops the running Archiveopteryx servers in the correct order.
.IP "aox restart [-v]"
Restarts the servers in the correct order (currently equivalent to start
&& stop).
.IP "aox show status [-v]"
Displays a summary of the running Archiveopteryx servers.
.IP "aox show configuration [-p -v] [variable-name]"
Displays variables configured in
.IR archiveopteryx.conf .
.IP
If a
.I variable-name
is specified, only that variable is displayed.
.IP
The -v flag displays only the value of the variable.
.IP
The -p flag restricts the results to variables whose value has been
changed from the default.
.IP
.I configuration
may be abbreviated as
.IR cf .
.IP "aox show build"
Displays the build settings used for this installation (as configured
in Jamsettings).
.IP "aox show counts [-f]"
Displays the number of rows in the most important tables, as well as the
total size of the mail stored.
.IP
The -f flag causes it to collect slow-but-accurate statistics. Without
it, by default, you get quick estimates (more accurate after VACUUM
ANALYSE).
.IP "aox show queue"
Displays a list of all mail queued for delivery to a smarthost.
.IP "aox show schema"
Displays the revision of the existing database schema.
.IP "aox upgrade schema [-n]"
Checks that the database schema is one that this version of
Archiveopteryx is compatible with, and updates it if needed.
.IP
The -n flag causes aox to perform the SQL statements for the schema
upgrade and report on their status without COMMITing the transaction
(i.e. see what the upgrade would do, without doing anything).
.IP "aox update database"
Performs any updates to the database contents which are too slow for
inclusion in
.IR "aox upgrade schema" .
This command is meant to be used while the server is running. It does
its work in small chunks, so it can be restarted at any time, and is
tolerant of interruptions.
.IP "aox tune database <mostly-writing|mostly-reading|advanced-reading>"
Adjusts the database indices and configuration to suit expected usage
patterns.
.IP "aox list mailboxes [-d] [-o username] [pattern]"
Displays a list of mailboxes matching the specified shell glob pattern.
Without a pattern, all mailboxes are listed.
.IP
The -d flag includes deleted mailboxes in the list.
.IP
The "-o username" flag restricts the list to mailboxes owned by the
specified user.
.IP
The -s flag shows a count of messages and the total size of the messages
in each mailbox.
.IP
.I ls
is an acceptable abbreviation for
.IR list .
.IP "aox list users [pattern]"
Displays a list of users matching the specified shell glob pattern.
Without a pattern, all users are listed.
.IP "aox list aliases [pattern]"
Displays a list of aliases where either the address or the target
mailbox matches the specified shell glob pattern. Without a pattern,
all aliases are listed.
.IP "aox list rights <mailbox> [username]"
Displays a list of users and the rights they have been granted to the
specified mailbox. If a username is given, only that user's rights are
displayed.
.IP "aox add user <username> <password> <email-address>"
.IP "aox add user -p <username> <email-address>"
Creates a new Archiveopteryx user with the specified username, password, and
email address. If the
.I -p
flag is specified, the password is read interactively, instead of from
the command-line.
.IP
.I create
and
.I new
are acceptable abbreviations for
.IR add .
.IP "aox delete user [-f] <username>"
Deletes the specified Archiveopteryx user. If
.I -f
is specified, any mailboxes owned by the user are also deleted.
.IP
.I del
and
.I remove
are acceptable abbreviations for
.IR delete .
.IP "aox change password <username> <new-password>"
.IP "aox change password -p <username>"
Changes the specified user's password. If the
.I -p
flag is specified, the password is read interactively, instead of from
the command-line.
.IP "aox change username <username> <new-username>"
Renames the specified user.
.IP "aox change address <username> <new-address>"
Changes the specified user's email address.
.IP "aox add mailbox <name> [username]"
Creates a new mailbox with the specified name and, if a username is
specified, owned by that user.
.IP
The mailbox
.I name
must be fully-qualified (begin with /), unless a
.I username
is specified, in which case unqualified names are assumed to be under
the user's home directory.
.IP "aox delete mailbox [-f] <name>"
Deletes the specified mailbox.
.IP
If
.I -f
is specified, the mailbox and any messages it contains are permanently
deleted. Otherwise, only empty mailboxes are deleted.
.IP "aox add view <name> <source> <owner> <search>"
Creates a new view mailbox which applies the specified search
on the specified source mailbox. When a new message is added
to the source, and it matches the search, it will automatically
be added to the view as well.
.IP "aox add alias <address> <mailbox>"
Creates an alias that instructs the server to accept mail to the given
.I address
and deliver it to the specified
.IR mailbox .
.IP "aox delete alias <address>"
Deletes an alias, if one exists, for the given
.IR address .
.IP "aox setacl [-d] <mailbox> <identifier> <rights>"
Assigns the specified rights to the given identifier on the mailbox. If
the rights begin with + or -, the specified rights are added to or
subtracted from the existing rights; otherwise, the rights are set to
exactly those given.
.IP
With -d, the identifier's rights are deleted altogether.
.IP
A summary of the changes made is displayed when the operation completes.
.IP "aox undelete <mailbox> <search>"
Searches for deleted messages in the specified mailbox and
restores those that match the search.
.PP
Messages can be restored after an IMAP EXPUNGE or POP3 DELE
until aox vacuum permanently removes them after the configured
.IR undelete-time .
.PP
Example: aox undelete /users/fred/inbox from example.com
.IP "aox vacuum"
Permanently deletes messages that were marked for deletion more than
.I undelete-time
days ago, and removes any bodyparts that are no longer used.
.IP
This is not a replacement for running VACUUM ANALYSE on the database
(either with vacuumdb or via autovacuum).
.IP
This command should be run (we suggest daily) via crontab.
.IP "aox anonymise <file>"
Reads a mail message from the named file, obscures most or all content
and prints the result on stdout. The output resembles the original
closely enough to be used in a bug report.
.IP "aox reparse"
Looks for messages that "arrived but could not be stored" and tries to
parse them using workarounds that have been added more recently. If it
succeeds, the new message is injected and the old one deleted.
.IP "aox grant privileges <username>"
makes sure that the named user has all the permissions needed for the
db-user (i.e., and unprivileged user), and no more.
.IP "aox check config"
reads the configuration files and reports any problems that it finds.
.SH OPTIONS
The -v flag enables (slightly) more verbose diagnostic output wherever
it is supported (see the descriptions of each command above).
.SH EXAMPLES
To add a user called "nirmala", whose password is "angstskrik" and
whose main email address is "nirmala@example.com":
.IP
aox add user nirmala angstskrik nirmala@example.com
.PP
To change Nirmala's password to "temmelig hemmelig":
.IP
aox change password nirmala 'temmelig hemmelig'
.PP
To remove that user:
.IP
aox remove user nirmala
.SH DIAGNOSTICS
The return code of
.B aox
is zero if all goes well, and a non-zero in case of errors.
.PP
Diagnostics are logged using Archiveopteryx's
.BR logd (8),
just like the servers do. Disasters are also logged via stderr.
.SH BUGS
There is no command-line option to set the configuration file.
.SH AUTHOR
The Archiveopteryx Developers, info@aox.org.
.SH VERSION
This man page covers Archiveopteryx version 3.2.0, released 2013-12-02,
http://archiveopteryx.org/3.1.3
.SH SEE ALSO
.BR archiveopteryx (8),
.BR archiveopteryx.conf (5),
http://archiveopteryx.org
